@@ -1,6 +1,6 @@
 from threading import Event, Lock
 from miro import prefs
-import miro.platform.config
+import miro.plat.config
 
 _data = {}
 _dataLock = Lock()
@@ -9,10 +9,10 @@ _ready = Event()
 
 __callbacks = set()
 
-def addChangeCallback(callback):
+def add_change_callback(callback):
     __callbacks.add(callback)
 
-def removeChangeCallback(callback):
+def remove_change_callback(callback):
     __callbacks.discard(callback)
 
 def setDictionary(d):
@@ -42,7 +42,7 @@ def get(descriptor):
         if descriptor.key in _data:
             return _data[descriptor.key]
         elif descriptor.platformSpecific:
-            return miro.platform.config.get(descriptor)
+            return miro.plat.config.get(descriptor)
         else:
             return descriptor.default
     finally:
