@@ -1,5 +1,5 @@
 # Miro - an RSS based video player application
-# Copyright (C) 2005-2008 Participatory Culture Foundation
+# Copyright (C) 2005-2009 Participatory Culture Foundation
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -64,15 +64,15 @@ from miro import prefs
 from miro import util
 from miro import schema as schema_mod
 from miro import eventloop
-from miro import app
 from miro import dialogs
 import logging
 from zipfile import ZipFile
 import tempfile
-from random import randrange, seed
+from random import randrange
 import os.path
-from miro.platform.utils import exit
+from miro.plat.utils import exit
 
+# FIXME - bsddb3.db is never used
 try:
     import bsddb.db
 except ImportError:
@@ -118,7 +118,7 @@ class SavableObject:
     classString -- specifies the class this object was converted from.  
     savedData -- dict that stores the data we've saved.
     
-    The SavableObject class is guarenteed to never change.  This means we can
+    The SavableObject class is guaranteed to never change.  This means we can
     always safely unpickle them.
     """
 
@@ -147,12 +147,12 @@ class ConverterBase(object):
 
     The subclasses of ConverterBase are responsible for creating a
     convertObject method, and adding validation to the convertData method
-    (SavableConverter does validation at the begining, SavableUnconverter does
+    (SavableConverter does validation at the beginning, SavableUnconverter does
     it at the end).
     """
 
     def __init__(self, objectSchemas=None):
-        """Contruct a converter.  object schemas is a list of ObjectSchema
+        """Construct a converter.  object schemas is a list of ObjectSchema
         objects to use.  If none is given (the default), the schemas will be
         taken from miro.schema.objectSchemas.
         """
@@ -287,7 +287,7 @@ class ConverterBase(object):
         pass
 
     def getSourceAttr(self, object, attrName):
-        """Retrive the value of an attribute on a source object."""
+        """Retrieve the value of an attribute on a source object."""
         try:
             return getattr(object, attrName)
         except AttributeError:
@@ -523,7 +523,7 @@ def getObjects(pathname, convertOnFail):
             from miro import olddatabaseupgrade
             olddatabaseupgrade.convertOldDatabase(pathname)
             objects = restoreObjectList(pathname)
-            logging.info ("*** Conversion Successfull ***")
+            logging.info ("*** Conversion Successful ***")
         else:
             raise
     except ImportError, e:
@@ -546,9 +546,9 @@ def getObjects(pathname, convertOnFail):
         databasesanity.checkSanity(objects, quiet=True, 
                 reallyQuiet=(not util.chatter))
     except databasesanity.DatabaseInsaneError, e:
-        signals.system.failedExn("When restoring database", e)
+        signals.system.failed_exn("When restoring database", e)
         # if the database fails the sanity check, try to restore it anyway.
-        # It's better than notheing
+        # It's better than nothing
     skipOnRestore = oldSkipOnRestore
     if not skipOnRestore:
         for object in objects:
@@ -595,14 +595,14 @@ class LiveStorageBDB:
                         self.closeInvalidDB()
                         try:
                             restoreDatabase()
-                        except KeyboardInterrupt:
+                        except (SystemExit, KeyboardInterrupt):
                             raise
                         except:
                             logging.exception ("Error restoring old database")
                         self.saveDatabase()
                     else:
                         self.loadDatabase()
-                except KeyboardInterrupt:
+                except (SystemExit, KeyboardInterrupt):
                     raise
                 except databaseupgrade.DatabaseTooNewError:
                     raise
@@ -654,6 +654,8 @@ class LiveStorageBDB:
                     output_object(value)
                     indentation = indentation - 1
                     indent()
+                elif isinstance (value, unicode):
+                    output.write (value.encode('ascii', 'replace'))
                 else:
                     output.write (str(value))
                 output.write ('</%s>\n' % (key,))
@@ -696,7 +698,7 @@ class LiveStorageBDB:
         database.confirmDBThread()
         try:
             os.makedirs(self.dbPath)
-        except KeyboardInterrupt:
+        except (SystemExit, KeyboardInterrupt):
             raise
         except:
             pass
@@ -711,7 +713,7 @@ class LiveStorageBDB:
         database.confirmDBThread()
         try:
             self.db.close()
-        except KeyboardInterrupt:
+        except (SystemExit, KeyboardInterrupt):
             raise
         except:
             pass
@@ -731,7 +733,7 @@ class LiveStorageBDB:
                 try:
                     savable = cPickle.loads(data)
                     savables.append(savable)
-                except KeyboardInterrupt:
+                except (SystemExit, KeyboardInterrupt):
                     raise
                 except:
                     logging.info ('Error loading data in upgradeDatabase')
@@ -802,7 +804,7 @@ class LiveStorageBDB:
                     savable = cPickle.loads(data)
                     object = savableToObject(savable)
                     objects.append(object)
-                except KeyboardInterrupt:
+                except (SystemExit, KeyboardInterrupt):
                     raise
                 except:
                     logging.info ("Error loading data in loadDatabase")
@@ -857,21 +859,30 @@ class LiveStorageBDB:
             self.toUpdate = set()
             self.toRemove = set()
             if self.errorState:
-                title = _("%s database save succeeded") % (config.get(prefs.SHORT_APP_NAME), )
-                description = _("The database has been successfully saved. "
-                               "It is now safe to quit without losing any "
-                               "data.")
+                title = _("%(appname)s database save succeeded",
+                          {"appname": config.get(prefs.SHORT_APP_NAME)})
+                description = _(
+                    "The database has been successfully saved. It is now safe "
+                    "to quit without losing any data."
+                )
                 dialogs.MessageBoxDialog(title, description).run()
                 self.errorState = False
         except bsddb.db.DBNoSpaceError, err:
             if not self.errorState:
-                title = _("%s database save failed") % (config.get(prefs.SHORT_APP_NAME), )
-                description = _("%s was unable to save its database: Disk Full.\nWe suggest deleting files from the full disk or simply deleting some movies from your collection.\nRecent changes may be lost.") % (config.get(prefs.LONG_APP_NAME)) 
+                title = _("%(appname)s database save failed",
+                          {"appname": config.get(prefs.SHORT_APP_NAME)})
+                description = _(
+                    "%(appname)s was unable to save its database: Disk Full.\n"
+                    "We suggest deleting files from the full disk or simply "
+                    "deleting some movies from your collection.\n"
+                    "Recent changes may be lost.",
+                    {"appname": config.get(prefs.SHORT_APP_NAME)}
+                )
                 dialogs.MessageBoxDialog(title, description).run()
                 self.errorState = True
             try:
                 self.txn.abort()
-            except KeyboardInterrupt:
+            except (SystemExit, KeyboardInterrupt):
                 raise
             except:
                 # if we tried to do a commit and failed an abort doesn't work
@@ -903,7 +914,7 @@ class LiveStorageBDB:
             self.toRemove.add (object)
             try:
                 self.toUpdate.remove (object)
-            except KeyboardInterrupt:
+            except (SystemExit, KeyboardInterrupt):
                 raise
             except:
                 pass
@@ -922,7 +933,7 @@ class LiveStorageBDB:
             for logfile in self.dbenv.log_archive(bsddb.db.DB_ARCH_ABS):
                 try:
                     os.remove(logfile)
-                except KeyboardInterrupt:
+                except (SystemExit, KeyboardInterrupt):
                     raise
                 except:
                     pass
@@ -970,10 +981,12 @@ class LiveStorage:
                             logging.info("Upgrading from previous version of database")
                             try:
                                 LiveStorageBDB()
+                            except (SystemExit, KeyboardInterrupt):
+                                raise
                             except:
                                 logging.warning("Upgrading from previous version of database failed")
                         self.saveDatabase()
-                except KeyboardInterrupt:
+                except (SystemExit, KeyboardInterrupt):
                     raise
                 except databaseupgrade.DatabaseTooNewError:
                     raise
@@ -984,7 +997,13 @@ class LiveStorage:
             eventloop.addIdle(self.checkpoint, "Remove Unused Database Logs")
             end = clock()
             if end - start > 0.05 and util.chatter:
-                logging.timing ("Database load slow: %.3f", end - start)
+                logging.timing("Database load slow: %.3f", end - start)
+            try:
+                import stat
+                logging.info("Database size on disk (in bytes): %s", os.stat(self.dbPath)[stat.ST_SIZE])
+                logging.info("Database object count: %s", database.defaultDatabase.count_objects())
+            except IOError:
+                logging.error("IOError when statting database file.")
         except sql.DatabaseError, e:
             logging.error(e)
             raise
@@ -1048,6 +1067,8 @@ class LiveStorage:
                     output_object(value)
                     indentation = indentation - 1
                     indent()
+                elif isinstance (value, unicode):
+                    output.write (value.encode('ascii', 'replace'))
                 else:
                     output.write (str(value))
                 output.write ('</%s>\n' % (key,))
@@ -1074,6 +1095,8 @@ class LiveStorage:
         if not self.closed:
             try:
                 self.conn.close()
+            except (SystemExit, KeyboardInterrupt):
+                raise
             except:
                 traceback.print_exc()
         try:
@@ -1094,6 +1117,8 @@ class LiveStorage:
                 zipfile.close()
                 logging.info("Database backed up to %s" % tempfilename)
                 return tempfilename
+            except (SystemExit, KeyboardInterrupt):
+                raise
             except:
                 traceback.print_exc()
         finally:
@@ -1139,7 +1164,7 @@ class LiveStorage:
                 try:
                     savable = cPickle.loads(str(data))
                     savables.append(savable)
-                except KeyboardInterrupt:
+                except (SystemExit, KeyboardInterrupt):
                     raise
                 except:
                     logging.info ('Error loading data in upgradeDatabase')
@@ -1202,7 +1227,7 @@ class LiveStorage:
                 savable = cPickle.loads(str(data))
                 object = savableToObject(savable)
                 objects.append(object)
-            except KeyboardInterrupt:
+            except (SystemExit, KeyboardInterrupt):
                 raise
             except:
                 logging.info ("Error loading data in loadDatabase")
@@ -1231,6 +1256,7 @@ class LiveStorage:
 
     def close(self):
         database.confirmDBThread()
+        self.cursor.execute("VACUUM")
         self.runUpdate()
         self.closed = True
         self.cursor.close()
@@ -1259,17 +1285,26 @@ class LiveStorage:
             self.toUpdate = set()
             self.toRemove = set()
             if self.errorState:
-                title = _("%s database save succeeded") % (config.get(prefs.SHORT_APP_NAME), )
-                description = _("The database has been successfully saved. "
-                               "It is now safe to quit without losing any "
-                               "data.")
+                title = _("%(appname)s database save succeeded",
+                          {"appname": config.get(prefs.SHORT_APP_NAME)})
+                description = _(
+                    "The database has been successfully saved. It is now safe to quit "
+                    "without losing any data."
+                )
                 dialogs.MessageBoxDialog(title, description).run()
                 self.errorState = False
         except sql.DatabaseError, e:
             print e
             if not self.errorState:
-                title = _("%s database save failed") % (config.get(prefs.SHORT_APP_NAME), )
-                description = _("%s was unable to save its database: Disk Full.\nWe suggest deleting files from the full disk or simply deleting some movies from your collection.\nRecent changes may be lost.") % (config.get(prefs.LONG_APP_NAME)) 
+                title = _("%(appname)s database save failed",
+                          {"appname": config.get(prefs.SHORT_APP_NAME)})
+                description = _(
+                    "%(appname)s was unable to save its database: Disk Full.\n"
+                    "We suggest deleting files from the full disk or simply deleting "
+                    "some movies from your collection.\n"
+                    "Recent changes may be lost.",
+                    {"appname": config.get(prefs.SHORT_APP_NAME)}
+                )
                 dialogs.MessageBoxDialog(title, description).run()
                 self.errorState = True
                 self.updating=False
@@ -1300,7 +1335,7 @@ class LiveStorage:
             self.toRemove.add (object)
             try:
                 self.toUpdate.remove (object)
-            except KeyboardInterrupt:
+            except (SystemExit, KeyboardInterrupt):
                 raise
             except:
                 pass
