@@ -15,13 +15,10 @@ import os
 from miro import gtcache
 import gettext
 from miro import signals
-from miro.platform import resources
-from miro.frontends.html import template
+from miro.plat import resources
 from miro import util
-from miro.frontends.html.template_compiler import TemplateError
-from miro.frontends.html import template_compiler
 
-from miro.test.framework import DemocracyTestCase
+from miro.test.framework import MiroTestCase
 
 class UnicodeFeedTestCase(framework.EventLoopTest):
     def setUp(self):
@@ -77,21 +74,21 @@ class UnicodeFeedTestCase(framework.EventLoopTest):
         # We need to explicitly check that the type is unicode because
         # Python automatically converts bytes strings to unicode strings
         # using the current system character set
-        self.assertEqual(type(myFeed.getTitle()), types.UnicodeType)
-        self.assertEqual(u"Chinese Numbers \u25cb\u4e00\u4e8c\u4e09\u56db\u4e94\u516d\u4e03\u516b\u4e5d",myFeed.getTitle())
+        self.assertEqual(type(myFeed.get_title()), types.UnicodeType)
+        self.assertEqual(u"Chinese Numbers \u25cb\u4e00\u4e8c\u4e09\u56db\u4e94\u516d\u4e03\u516b\u4e5d",myFeed.get_title())
 
         # The description is the same, but surrounded by a <span>
-        self.assertEqual(type(myFeed.getDescription()), types.UnicodeType)
-        self.assertEqual(u"<span>Chinese Numbers \u25cb\u4e00\u4e8c\u4e09\u56db\u4e94\u516d\u4e03\u516b\u4e5d</span>",myFeed.getDescription())
+        self.assertEqual(type(myFeed.get_description()), types.UnicodeType)
+        self.assertEqual(u"<span>Chinese Numbers \u25cb\u4e00\u4e8c\u4e09\u56db\u4e94\u516d\u4e03\u516b\u4e5d</span>",myFeed.get_description())
 
         items = database.defaultDatabase.filter(lambda x:x.__class__ == item.Item)
         self.assertEqual(items.len(),1)
         i = items[0]
-        self.assertEqual(type(i.getTitle()), types.UnicodeType)
-        self.assertEqual(u"\u25cb\u4e00\u4e8c\u4e09\u56db\u4e94\u516d\u4e03\u516b\u4e5d",i.getTitle())
+        self.assertEqual(type(i.get_title()), types.UnicodeType)
+        self.assertEqual(u"\u25cb\u4e00\u4e8c\u4e09\u56db\u4e94\u516d\u4e03\u516b\u4e5d",i.get_title())
 
-        self.assertEqual(type(i.getDescription()), types.UnicodeType)
-        self.assertEqual(u"<span>\u25cb\u4e00\u4e8c\u4e09\u56db\u4e94\u516d\u4e03\u516b\u4e5d</span>",i.getDescription())
+        self.assertEqual(type(i.get_description()), types.UnicodeType)
+        self.assertEqual(u"<span>\u25cb\u4e00\u4e8c\u4e09\u56db\u4e94\u516d\u4e03\u516b\u4e5d</span>",i.get_description())
 
     def forceFeedParserCallback(self, myFeed):
         # a hack to get the feed to update without eventloop
@@ -113,8 +110,8 @@ class UnicodeFeedTestCase(framework.EventLoopTest):
         self.processIdles()
         self.assertEqual(len(myFeed.items), 1)
         myItem = myFeed.items[0]
-        self.assertEqual(len(myItem.getTitle()), 14)
-        self.assertEqual(myItem.getTitle(), u"H\xe4ppy Birthday")
+        self.assertEqual(len(myItem.get_title()), 14)
+        self.assertEqual(myItem.get_title(), u"H\xe4ppy Birthday")
 
     # This is latin1 HTML that claims to be Latin 1
     def testLatin1HTML(self):
@@ -131,8 +128,8 @@ class UnicodeFeedTestCase(framework.EventLoopTest):
         myFeed.update()
         self.assertEqual(len(myFeed.items), 1)
         myItem = myFeed.items[0]
-        self.assertEqual(len(myItem.getTitle()), 14)
-        self.assertEqual(myItem.getTitle(), u"H\xe4ppy Birthday")
+        self.assertEqual(len(myItem.get_title()), 14)
+        self.assertEqual(myItem.get_title(), u"H\xe4ppy Birthday")
 
     # This is latin1 HTML that claims to be UTF-8
     def testInvalidLatin1HTML(self):
@@ -149,8 +146,8 @@ class UnicodeFeedTestCase(framework.EventLoopTest):
         myFeed.update()
         self.assertEqual(len(myFeed.items),1)
         myItem = myFeed.items[0]
-        self.assertEqual(len(myItem.getTitle()),14)
-        self.assertEqual(myItem.getTitle(), u"H\xe4ppy Birthday")
+        self.assertEqual(len(myItem.get_title()),14)
+        self.assertEqual(myItem.get_title(), u"H\xe4ppy Birthday")
 
     # This is utf-8 HTML that claims to be utf-8
     def testUTF8HTML(self):
@@ -167,8 +164,8 @@ class UnicodeFeedTestCase(framework.EventLoopTest):
         myFeed.update()
         self.assertEqual(len(myFeed.items),1)
         myItem = myFeed.items[0]
-        self.assertEqual(len(myItem.getTitle()),14)
-        self.assertEqual(myItem.getTitle(), u"H\xe4ppy Birthday")
+        self.assertEqual(len(myItem.get_title()),14)
+        self.assertEqual(myItem.get_title(), u"H\xe4ppy Birthday")
 
     def testUTF8HTMLLinks(self):
         [handle, self.filename] = mkstemp(".html")
@@ -298,101 +295,4 @@ class UnicodeFeedTestCase(framework.EventLoopTest):
         myFeed = feed.Feed(url)
         self.forceFeedParserCallback(myFeed)
         for item in myFeed.items:
-            u'booya' in item.getTitle().lower()
-
-    def testGetText(self):
-        # FIXME this only works on GTK platforms. See #3831
-        oldLang = None
-        try:
-            oldLang = os.environ["LANGUAGE"]
-        except:
-            pass
-        os.environ["LANGUAGE"] = "fr"
-        gtcache._gtcache = {}
-
-        gettext.bindtextdomain("miro",resources.path("../../locale"))
-        gettext.textdomain("miro")
-        gettext.bind_textdomain_codeset("miro","UTF-8")
-        self.assertEqual(gtcache.gettext("Settings"),u'R\xe9glages')
-        if oldLang is None:
-            del os.environ["LANGUAGE"]
-        else:
-            os.environ["LANGUAGE"] = oldLang
-
-    def testTemplates(self):
-        # This tests that templates output valid UTF-8
-        
-        # FIXME this only works on GTK platforms. See #3831
-        oldLang = None
-        try:
-            oldLang = os.environ["LANGUAGE"]
-        except:
-            pass
-        os.environ["LANGUAGE"] = "fr"
-        gtcache._gtcache = {}
-
-        gettext.bindtextdomain("miro",resources.path("../../locale"))
-        gettext.textdomain("miro")
-        gettext.bind_textdomain_codeset("miro","UTF-8")
-
-        out = template.fillStaticTemplate("unittest/simpleunicode", "gtk-x11", "noCookie")
-        self.assert_(type(out)==types.UnicodeType)
-        # We shouldn't find utf-8 versions of this text
-        self.assert_(out.find(u'<h1>H\xc3\xa4ppy Birthday</h1>') == -1)
-        self.assert_(out.find(u'<p>R\xc3\xa9glages</p>') == -1)
-
-        # We should find the unicode string
-        self.assert_(out.find(u"<h1>H\xe4ppy Birthday</h1>") != -1)
-        self.assert_(out.find(u"<p>R\xe9glages</p>") != -1)
-        if oldLang is None:
-            del os.environ["LANGUAGE"]
-        else:
-            os.environ["LANGUAGE"] = oldLang
-
-class TemplateCompilerTest(framework.DemocracyTestCase):
-    def testNonUnicode(self):
-        # genRepeatText
-        self.assertRaises(util.DemocracyUnicodeError,
-                          lambda : template_compiler.genRepeatText("out","123","    ","boo"))
-        self.assertRaises(util.DemocracyUnicodeError,
-                          lambda : template_compiler.genRepeatText("out","123","    ","Chinese Numbers \x25cb\x4e00\x4e8c\x4e09\x56db\x4e94\x516d\x4e03\x516b\x4e5d"))
-        self.assertEqual(u"    out.write(u'Chinese Numbers \\u25cb\\u4e00\\u4e8c\\u4e09\\u56db\\u4e94\\u516d\\u4e03\\u516b\\u4e5d')\n",
-                         template_compiler.genRepeatText("out","123","    ",u"Chinese Numbers \u25cb\u4e00\u4e8c\u4e09\u56db\u4e94\u516d\u4e03\u516b\u4e5d"))
-
-
-        # genRepeatTranslate
-        self.assertRaises(util.DemocracyUnicodeError,
-                          lambda : template_compiler.genRepeatTranslate("out","123","    ",("boo",{})))
-        self.assertRaises(util.DemocracyUnicodeError,
-                          lambda : template_compiler.genRepeatTranslate("out","123","    ",("Chinese Numbers \x25cb\x4e00\x4e8c\x4e09\x56db\x4e94\x516d\x4e03\x516b\x4e5d",{})))
-
-
-        # genRepeatTextHide
-        self.assertRaises(util.DemocracyUnicodeError,
-                          lambda : template_compiler.genRepeatTextHide("out","123","    ",(False,"boo")))
-        self.assertRaises(util.DemocracyUnicodeError,
-                          lambda : template_compiler.genRepeatTextHide("out","123","    ",(False, "Chinese Numbers \x25cb\x4e00\x4e8c\x4e09\x56db\x4e94\x516d\x4e03\x516b\x4e5d")))
-        self.assertRaises(util.DemocracyUnicodeError,
-                          lambda : template_compiler.genRepeatTextHide("out","123","    ",(True,"boo")))
-        self.assertRaises(util.DemocracyUnicodeError,
-                          lambda : template_compiler.genRepeatTextHide("out","123","    ",(True, "Chinese Numbers \x25cb\x4e00\x4e8c\x4e09\x56db\x4e94\x516d\x4e03\x516b\x4e5d")))
-
-        self.assertEqual(u"    if not (True):\n        out.write(u'Chinese Numbers \\u25cb\\u4e00\\u4e8c\\u4e09\\u56db\\u4e94\\u516d\\u4e03\\u516b\\u4e5d')\n",
-                         template_compiler.genRepeatTextHide("out","123","    ",(True, u"Chinese Numbers \u25cb\u4e00\u4e8c\u4e09\u56db\u4e94\u516d\u4e03\u516b\u4e5d")))
-
-        # genHideSection
-        self.assertRaises(util.DemocracyUnicodeError,
-                          lambda : template_compiler.genHideSection("out","123","    ",(False,[(lambda a,b,c,d: "boo","ignored")])))
-        self.assertRaises(util.DemocracyUnicodeError,
-                          lambda : template_compiler.genHideSection("out","123","    ",(False,[(lambda a,b,c,d: "Chinese Numbers \x25cb\x4e00\x4e8c\x4e09\x56db\x4e94\x516d\x4e03\x516b\x4e5d","ignored")])))
-        self.assertEqual(u'    if not (False):\nChinese Numbers \u25cb\u4e00\u4e8c\u4e09\u56db\u4e94\u516d\u4e03\u516b\u4e5d',
-                          template_compiler.genHideSection("out","123","    ",(False,[(lambda a,b,c,d: u"Chinese Numbers \u25cb\u4e00\u4e8c\u4e09\u56db\u4e94\u516d\u4e03\u516b\u4e5d","ignored")])))
-
-        # genQuoteAndFillAttr
-        self.assertRaises(util.DemocracyUnicodeError,
-                          lambda:template_compiler.genQuoteAndFillAttr("out","123","    ","boo"))
-        self.assertRaises(util.DemocracyUnicodeError,
-                          lambda:template_compiler.genQuoteAndFillAttr("out","123","    ","Chinese Numbers \x25cb\x4e00\x4e8c\x4e09\x56db\x4e94\x516d\x4e03\x516b\x4e5d"))
-        self.assertEqual(u"    out.write(quoteAndFillAttr(u'Chinese Numbers \\u25cb\\u4e00\\u4e8c\\u4e09\\u56db\\u4e94\\u516d\\u4e03\\u516b\\u4e5d',locals()))\n",
-                         template_compiler.genQuoteAndFillAttr("out","123","    ",u"Chinese Numbers \u25cb\u4e00\u4e8c\u4e09\u56db\u4e94\u516d\u4e03\u516b\u4e5d"))
-
+            u'booya' in item.get_title().lower()
